@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import contextlib
 
-__all__ = ('capture_exceptions',)
+__all__ = ("capture_exceptions",)
 
 
 @contextlib.contextmanager
